//
//  ViewController.m
//  ex_animateClockLabel
//
//  Created by yoshiyuki oshige on 2014/01/12.
//  Copyright (c) 2014年 yoshiyuki. All rights reserved.
//

#import "ViewController.h"

@interface ViewController ()
{
    // タイマーを保持するインスタンス変数
    NSTimer * _animateTimer;
    NSTimer * _clockTimer;
}

// ラベルをアウトレット接続してプロパティ宣言を挿入する
@property (weak, nonatomic) IBOutlet UILabel *clockLabel;

// アニメーションのメソッド
- (void)flyingAnimation;
// 日時表示のメソッド
- (void)updateClock;

@end

@implementation ViewController

// ビューが表示されたならば実行する
- (void)viewDidAppear:(BOOL)animated
{
    // ラベルをスタート位置に移動させる
    self.clockLabel.center = CGPointMake(480, 150);
    
    // flyingAnimationメソッドを5秒間隔で呼び出すタイマーを作る
    _animateTimer = [NSTimer scheduledTimerWithTimeInterval:5
                                                     target:self
                                                   selector:@selector(flyingAnimation)
                                                   userInfo:nil
                                                    repeats:YES];
    // updateClockメソッドを1秒間隔で呼び出すタイマーを作る
    _clockTimer = [NSTimer scheduledTimerWithTimeInterval:1
                                                   target:self
                                                 selector:@selector(updateClock)
                                                 userInfo:nil
                                                  repeats:YES];
}

// ラベルのフライングアニメーションを行う
- (void)flyingAnimation
{
    // ラベルの登場と退場
    [UIView animateWithDuration:0.5
                          delay: 0.0
                        options: UIViewAnimationOptionCurveEaseOut
                     animations:^{
                         // 画面の右から登場
                         self.clockLabel.center = CGPointMake(160, 150);
                     }
                     completion:^(BOOL finished){
                         // ラベルが指定位置まで到達したら
                         [UIView animateWithDuration:0.5
                                               delay: 3.0 // 3秒待つ
                                             options:UIViewAnimationOptionCurveEaseIn
                                          animations:^{
                                              // 画面の左へ退場
                                              self.clockLabel.center = CGPointMake(-160, 150);
                                          }
                                          completion:^(BOOL finished){
                                              // ラベルが退場したらスタート位置に戻す
                                              self.clockLabel.center = CGPointMake(480, 150);
                                              
                                          }];
                     }];
}

// ラベルの日時表示を更新する
- (void)updateClock
{
    // 現在時刻を作る
    NSDateFormatter *formatter = [[NSDateFormatter alloc]init];
    [formatter setDateFormat:@"yyyy/MM/dd HH:mm:ss"];
    NSString *now = [formatter stringFromDate:[NSDate date]];
    // ラベルに時刻を表示する
    self.clockLabel.text = now;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

@end
